@@ -213,6 +213,7 @@ class BaseRustSocket:
         self.remote.event_handler.clear_entity_events()
         # reset marker listener
         self.marker_listener.persistent_ids.clear()
+        self.marker_listener.highest_id = 0
 
         if connect:
             await self.connect()
@@ -297,6 +298,9 @@ class BaseRustSocket:
         :raises SmartDeviceRegistrationError
         """
 
+        if not self.remote.is_open():
+            raise ClientNotConnectedError("Client is not connected")
+
         def wrap_func(coro) -> RegisteredListener:
 
             if isinstance(coro, RegisteredListener):
@@ -466,6 +470,7 @@ class BaseRustSocket:
         add_events: bool = False,
         add_vending_machines: bool = False,
         override_images: dict = None,
+        add_grid: bool = False,
     ) -> Image:
         """
         Gets an image of the map from the server with the specified additions
@@ -474,6 +479,7 @@ class BaseRustSocket:
         :param add_events: To add the Event icons
         :param add_vending_machines: To add the vending icons
         :param override_images: To override the images pre-supplied with RustPlus.py
+        :param add_grid: To add the grid to the map
         :return Image: PIL Image
         """
         raise NotImplementedError("Not Implemented")
